<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="项目名称" prop="projectName">
        <el-input
          v-model="queryParams.projectName"
          placeholder="支持模糊查询"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="项目代码" prop="projectCode">
        <el-input
          v-model="queryParams.projectCode"
          placeholder="支持模糊查询"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="上报状态" prop="reportStatus">
        <el-select v-model="queryParams.reportStatus" @change="handleQuery" placeholder="请选择状态" clearable>
          <el-option label="已上报" value="0"></el-option>
          <el-option label="未上报" value="1"></el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="审批状态" prop="reportStatus">
        <el-select placeholder="请选择状态" clearable>
          <el-option label="已审批" value="0"></el-option>
          <el-option label="未审批" value="1"></el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="项目年限" prop="reportStatus">
        <el-select placeholder="下拉选择" clearable>
          <el-option label="2024" value="2024"></el-option>
          <el-option label="2025" value="2025"></el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="项目月度" prop="reportStatus">
        <el-select placeholder="下拉选择" clearable>
          <el-option label="1月度" value="1"></el-option>
          <el-option label="2月度" value="2"></el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="项目季度" prop="reportStatus">
        <el-select placeholder="下拉选择" clearable>
          <el-option label="1季度" value="1"></el-option>
          <el-option label="2季度" value="2"></el-option>
          <el-option label="3季度" value="3"></el-option>
          <el-option label="4季度" value="4"></el-option>
        </el-select>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleQuery"
        >查询</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleReset"
        >重置</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="recordList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="ID" align="center" prop="id" />
      <el-table-column label="项目名称" align="center" prop="projectName" />
      <el-table-column label="上报状态" align="center" prop="reportStatus" >
        <template slot-scope="scope">
          {{ scope.row.reportStatus === 0 ? '已上报' : '未上报' }}
        </template>
      </el-table-column>
      <el-table-column label="项目码" align="center" prop="" />
      <el-table-column label="项目代码" align="center" prop="projectCode" />
      <el-table-column label="项目类型" align="center" prop="projectType" >
        <template slot-scope="scope">
          {{
            scope.row.projectType === 0 ? '房屋建筑' :
              scope.row.projectType === 1 ? '城市基础设施' :
                scope.row.projectType === 2 ? '交通运输' :
                  scope.row.projectType === 3 ? '水利' :
                    scope.row.projectType === 4 ? '能源' :
                      scope.row.projectType === 5 ? '非煤矿山' :
                        scope.row.projectType === 6 ? '其他' : '未知'
          }}
        </template>
      </el-table-column>
      <el-table-column label="项目阶段" align="center" prop="projectPhase" >
        <template slot-scope="scope">
          {{
            scope.row.projectPhase === 0 ? '储备规划阶段' :
              scope.row.projectPhase === 1 ? '项目前期阶段' :
                scope.row.projectPhase === 2 ? '实施阶段' :
                  scope.row.projectPhase === 3 ? '竣工投用阶段' :
                    '未知'
          }}
        </template>
      </el-table-column>
      <el-table-column label="月度" align="center" prop="monthStatus" >
        <template slot-scope="scope">
          {{ scope.row.monthStatus === 0 ? '已上报' : '未上报' }}
        </template>
      </el-table-column>
      <el-table-column label="季度" align="center" prop="seasonStatus" >
        <template slot-scope="scope">
          {{ scope.row.seasonStatus === 0 ? '已上报' : '未上报' }}
        </template>
      </el-table-column>
      <el-table-column label="年度" align="center" prop="yearStatus" >
        <template slot-scope="scope">
          {{ scope.row.yearStatus === 0 ? '已上报' : '未上报' }}
        </template>
      </el-table-column>
      <el-table-column label="项目状态" align="center" prop="projectStatus" >
        <template slot-scope="scope">
          {{
            scope.row.projectStatus === 0 ? '未开工' :
              scope.row.projectStatus === 1 ? '已开工' :
                scope.row.projectStatus === 2 ? '已竣工' :
                  scope.row.projectStatus === 3 ? '暂停' :
                    '未知状态'
          }}
        </template>
      </el-table-column>
      <el-table-column label="投资类别" align="center" prop="investType" >
        <template slot-scope="scope">
          {{
            scope.row.investType === 0 ? '企业投资' :
              scope.row.investType === 1 ? '政府投资' :
                scope.row.investType === 2 ? '外商投资' :
                  scope.row.investType === 3 ? '境外投资' :
                    '未知类型'
          }}
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handlePlanRecord(scope.row)"
          >查看</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />
  </div>
</template>

<script>
import { getList, getRecord, delRecord, addRecord, updateRecord } from "@/api/projectPlan/index";

export default {
  name: "index",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 项目计划记录表格数据
      recordList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询项目计划记录列表 */
    getList() {
      this.loading = true;
      getList(this.queryParams).then(response => {
        this.recordList = response.data;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        projectInfoId: null,
        planId: null,
        engineeringInfoId: null,
        planTime: null,
        planTimeFlag: null,
        createTime: null,
        reportStatus: null,
        actualInvest: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加项目计划记录";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getRecord(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改项目计划记录";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateRecord(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addRecord(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除项目计划记录编号为"' + ids + '"的数据项？').then(function() {
        return delRecord(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('plan/record/export', {
        ...this.queryParams
      }, `record_${new Date().getTime()}.xlsx`)
    },
    /** 查看项目计划记录 */
    handlePlanRecord(row) {
      this.$router.push({
        path: '/projectManage/progressRecord',
        query: {
          data: JSON.stringify(row)
        }
      })
    }
  }
};
</script>
